geekstudio
=========

Please change the description here (for your project)

这里需要改成自己的项目信息，比如：一个pypi的项目模板（种子项目）

Package hosted on [`pypi`_] and powered by [`pypi-seed`_]

Installation / 安装
--------------------------

::

    pip install geekstudio


More Info
--------------------------

Author levin6

.. _`pypi`: https://pypi.org/
.. _`pypi-seed`: https://pypi.org/project/pypi-seed/

